@@ -177,6 +177,11 @@
 #define TITRAQ_IDXSTATERROR     0
 #define TITRAQ_IDXSTATCOLOR     1
 
+// Offsets
+#define TITRAQ_OFFSETYEAR       4
+#define TITRAQ_OFFSETMONTH      7
+#define TITRAQ_OFFSETHOUR       2
+
 // Values
 #define TITRAQ_MARGIN           10          // Default layout margin
 #define TITRAQ_SPACING          6           // Default layout spacing
