@@ -168,8 +168,11 @@ protected slots:
     void selAll(void);                  // Edit menu select all
     void inplaceEdit(int, int, int, const QPoint &); // Enter in place edit mode
     void updEdit(int, int nCol = 0);    // Update edit controls
-    void validateData(int, int);        // Validate one row of matrix data
+    void validateData(void);            // Validate current row of matrix data
+    void validateData(int, int);        // Validate specified row of matrix data
     void updSizes(int, int, int);       // Update edit sizes
+    void calcCrc(void);                 // Calculate CRC of current row
+    void calcCrc(int, int);             // Calculate CRC of specified row
     void dataChanged(int, int);         // Timesheet data changed
     void updateLine(const QString &);   // Update line number column
     void updateUser(const QString &);   // Update user column
